@@ -40,6 +40,9 @@ const Cc = Components.classes;
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
+const APPLICATION_CID = Components.ID("fe74cf80-aa2d-11db-abbd-0800200c9a66");
+const APPLICATION_CONTRACTID = "@mozilla.org/fuel/application;1";
+
 //=================================================
 // Singleton that holds services and utilities
 var Utilities = {
@@ -668,21 +671,22 @@ function Application() {
 // Application implementation
 Application.prototype = {
   // for nsIClassInfo + XPCOMUtils
-  classID:          Components.ID("fe74cf80-aa2d-11db-abbd-0800200c9a66"),
+  classID:          APPLICATION_CID,
 
   // redefine the default factory for XPCOMUtils
   _xpcom_factory: ApplicationFactory,
 
   // for nsISupports
   QueryInterface : XPCOMUtils.generateQI([Ci.fuelIApplication, Ci.extIApplication,
-                                          Ci.nsIObserver, Ci.nsIClassInfo]),
+                                          Ci.nsIObserver]),
 
-  getInterfaces : function app_gi(aCount) {
-    var interfaces = [Ci.fuelIApplication, Ci.extIApplication, Ci.nsIObserver,
-                      Ci.nsIClassInfo];
-    aCount.value = interfaces.length;
-    return interfaces;
-  },
+  // for nsIClassInfo
+  classInfo: XPCOMUtils.generateCI({classID: APPLICATION_CID,
+                                    contractID: APPLICATION_CONTRACTID,
+                                    interfaces: [Ci.fuelIApplication,
+                                                 Ci.extIApplication,
+                                                 Ci.nsIObserver],
+                                    flags: Ci.nsIClassInfo.SINGLETON}),
 
   // for nsIObserver
   observe: function app_observe(aSubject, aTopic, aData) {
@@ -1274,19 +1278,9 @@ extApplication.prototype = {
     this._registered = {"unload": true};
   },
 
-  // for nsIClassInfo
-  flags : Ci.nsIClassInfo.SINGLETON,
-  implementationLanguage : Ci.nsIProgrammingLanguage.JAVASCRIPT,
-
-  getInterfaces : function app_gi(aCount) {
-    var interfaces = [Ci.extIApplication, Ci.nsIObserver, Ci.nsIClassInfo];
-    aCount.value = interfaces.length;
-    return interfaces;
-  },
-
-  getHelperForLanguage : function app_ghfl(aCount) {
-    return null;
-  },
+  classInfo: XPCOMUtils.generateCI({interfaces: [Ci.extIApplication,
+                                                 Ci.nsIObserver],
+                                    flags: Ci.nsIClassInfo.SINGLETON}),
 
   // extIApplication
   get id() {
@@ -1403,7 +1397,7 @@ extApplication.prototype = {
 
   QueryInterface : XPCOMUtils.generateQI([Ci.extIApplication, Ci.nsISupportsWeakReference])
 };
-//@line 720 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/fuel/src/fuelApplication.js"
+//@line 724 "/export/home/mozilla/packages/BUILD/SFWfirefox/mozilla/browser/fuel/src/fuelApplication.js"
 
 // set the proto, defined in extApplication.js
 Application.prototype.__proto__ = extApplication.prototype;
